# New in 0.14.3 (2021-10-19)

Bug fix.

## Changes

-   Bug fix to {func}`~scvi.model.base.BaseModelClass` to retain tensors registered by `register_tensor_from_anndata` ([#1235]).
-   Expose an instance of our `DocstringProcessor` to aid in documenting derived implementations of `setup_anndata` method ([#1235]).

## Contributors

-   [@adamgayoso]
-   [@jjhong922]
-   [@watiss]

[#1235]: https://github.com/YosefLab/scvi-tools/pull/1235
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@watiss]: https://github.com/watiss
